pub trait DebugLog<E> {
// Required methods
fn log(&mut self, event: &E);
fn dl_rfd(&self) -> i32;
}Expand description
Implement for types that you want to have a debug log for. Implemented for Input and History in the ragout crate
Object Safety
This trait is Object safe